.. _User_Guide:

#####################################
 The Stoner Python Package User Guide
#####################################

.. rubric::C.S. Allen, M. Newman, R. Temple, S. Morely  and G. Burnell


.. toctree::
   :maxdepth: 3

   Introduction and Installation <install>
   Loading and Examining Data <datafile>
   Plotting Data <plotfile>
   Curve Fitting Data <curve_fitting>
   Further Manipulating and Analysis of Data <analysisfile>
   Working with Lots of Data Files <datafolder>
   Working with images <image>
   Cookbook <cookbook>
   Converting Scripts from older versions <upgrade>
   Developing and Extending <developer>
   Credits <credits>

